import React, { MouseEvent } from "react";
import { Card, Button, TextField } from "@mui/material";
import "@scss/forgot_password.scss";
import { useNavigate } from "react-router-dom";
import { yupResolver } from '@hookform/resolvers/yup';
import * as yup from "yup";
import { useForm } from "react-hook-form"

type Inputs = {
    email: string;
    password: string;
};

const schema = yup.object().shape({
    email: yup.string().email("Please provide a valid email").required("No email was provided")
}).required();


export default function ForgotPassword() {
    const navigate = useNavigate();
    const { register, formState: { errors },  handleSubmit } = useForm<Inputs>({
        resolver: yupResolver(schema), // yup, joi and even your own.
    });


    const {ref: emailRef, ...emailRegisterProps} = register("email");
    const emailProps = {
        ...emailRegisterProps,
        inputRef: emailRef,
        className: "textfield",
        id: "email",
        label: "Email",
        error: !!errors.email,
        helperText: errors?.email?.message,
    }

    function buttonCancel(e: MouseEvent<HTMLButtonElement>) {
        e.preventDefault();
        navigate("/login")
    }

    function onSubmit(data: Inputs) {
        console.log("There will be an API call now with the following data");
        console.table(data);
        console.log("You can now go to http://localhost:8080/reset to acces the reset form")
    }

    return (
        <main className="cardContainer">
            <form onSubmit={handleSubmit(onSubmit)}>
                <Card className="card">
                    <h3>Forgot Passowrd</h3>
                    <p>
                        If you have forgot your password, we can send you an email
                        with a link to reset it.
                    </p>
                    <TextField {...emailProps} />
                    <div className="buttons">
                        <Button
                            id="cancel"
                            variant="outlined"
                            onClick={buttonCancel}
                        >
                            Cancel
                        </Button>
                        <Button
                            type="submit"
                            id="submit"
                            variant="contained"
                        >
                            Submit
                        </Button>
                    </div>
                </Card>
            </form>
        </main>
    );
}
