import React from "react";
import { Card, Button, TextField } from "@mui/material"
import "@scss/login.scss"
import { Link, useNavigate } from "react-router-dom";
import { yupResolver } from '@hookform/resolvers/yup';
import * as yup from "yup";
import { useForm } from "react-hook-form"

type Inputs = {
    email: string;
    password: string;
};

const schema = yup.object().shape({
    email: yup.string().email("Please provide a valid email").required("No email was provided"),
    password: yup.string().required("No password was provided"),
}).required();

export default function Login() {
    const navigate = useNavigate();
    const { register, formState: { errors },  handleSubmit } = useForm<Inputs>({
        resolver: yupResolver(schema), // yup, joi and even your own.
    });

    function hash(s: string) {
        return `hash of '${s}' to be definied`;
    }

    const {ref: emailRef, ...emailRegisterProps} = register("email");

    const emailProps = {
        ...emailRegisterProps,
        inputRef: emailRef,
        className: "textField",
        name: "email",
        id: "email",
        label: "Email",
        error: !!errors.email,
        helperText: errors?.email?.message,
    }

    const {ref: passRef, ...passRegisterProps} = register("password");

    const passProps = {
        ...passRegisterProps,
        inputRef: passRef,
        className: "textField",
        name: "password",
        id: "password",
        label: "Password",
        error: !!errors.password,
        helperText: errors?.password?.message,
    }

    function onSubmit(data: Inputs) {
        console.log("There will be an API call now with the following data");
        data = { ...data, password: hash(data.password) }
        console.table(data);
        setTimeout(() => navigate("/?logged"), 3000)
    }


    return (
        <main className="cardContainer">
            <form onSubmit={handleSubmit(onSubmit)}>
                <Card className="card">
                    <h3>Login</h3>
                    <TextField {...emailProps} />
                    <TextField {...passProps}/>
                    <Button type="submit" id="submit" variant="contained">Login</Button>
                    <p>Forgot your <Link to="/forgot">password</Link>?</p>
                </Card>
            </form>
        </main>
    )
}
